CVFolds: CVFolds (from SuperLearner package)

CVFoldsR Documentation

CVFolds (from SuperLearner package)

Description

Creates a list of row numbers for the V-fold cross validation.

Usage

CVFolds(N, id, Y, cvControl)

Arguments

N

Sample size.

id

Optional cluster id variable. If present, all observations in the same cluster will always be in the same split.

Y

outcome.

cvControl

Control parameters for the cross-validation step. See SuperLearner.CV.control for details.

Value

A list of length V where each element in the list is a vector with the row numbers of the corresponding validation sample.


PLUCR documentation built on March 30, 2026, 5:08 p.m.