R_p: Risk function for Conditional Average Treatment Effect (CATE)

View source: R/objective_functions.R

R_pR Documentation

Risk function for Conditional Average Treatment Effect (CATE)

Description

Computes the risk function R_p for estimating the Conditional Average Treatment Effect (CATE). The function minimizes the squared error between psi(X) and delta_Y(X).

Usage

R_p(psi, X, delta_Mu)

Arguments

psi

A function that takes an input X and returns a numeric vector with values in the range [-1, 1].

X

A matrix of covariates of size n x d (input data in ⁠[0,1]⁠).

delta_Mu

A function of X that determines the contrast between primary outcomes.

Value

A numeric scalar representing the risk function value.


PLUCR documentation built on March 30, 2026, 5:08 p.m.