SL.grf: SL.grf

View source: R/SL.grf.R

SL.grfR Documentation

SL.grf

Description

This function trains conditional mean of a target variable for treated and control groups using SuperLearner, applying cross-validation to compute out-of-fold estimates.

Usage

SL.grf(Y, X, newX, family, obsWeights, ...)

Arguments

Y

outcome variable

X

training dataframe

newX

test dataframe

family

gaussian or binomial

obsWeights

observation-level weights

...

not used

Value

a list containing the predictions and the fitted object


PLUCR documentation built on March 30, 2026, 5:08 p.m.