SuperLearner.CV.control: SuperLearner.CV.control (from SuperLearner package)

SuperLearner.CV.controlR Documentation

SuperLearner.CV.control (from SuperLearner package)

Description

SuperLearner.CV.control (from SuperLearner package)

Usage

SuperLearner.CV.control(
  V = 10L,
  stratifyCV = FALSE,
  shuffle = TRUE,
  validRows = NULL
)

Arguments

V

Number of splits for the V-fold cross-validation step. The default is 10. In most cases, between 10 and 20 splits works well.

stratifyCV

Should the data splits be stratified by a binary response? Attempts to maintain the same ratio in each training and validation sample.

shuffle

Should the rows of X be shuffled before creating the splits.

validRows

Use this to pass pre-specified rows for the sample splits. The length of the list should be V and each entry in the list should contain a vector with the row numbers of the corresponding validation sample.

Value

A list containing the control parameters.


PLUCR documentation built on March 30, 2026, 5:08 p.m.