V_p: Oracular approximation of value function

View source: R/utils.R

V_pR Documentation

Oracular approximation of value function

Description

Computes the expected outcome under a policy determined by the previously optimized psi(X). The policy assigns treatment probabilistically based on sigma_beta(psi(X)), and the expected outcome is calculated using counterfactual outcomes.

Usage

V_p(
  psi,
  beta = 0.05,
  centered = FALSE,
  alpha = 0.1,
  B = 1e+06,
  ncov = 10L,
  scenario_mu = c("Linear", "Threshold", "Mix", "Linear2", "Null", "Realistic"),
  scenario_nu = c("Linear", "Threshold", "Mix", "Satisfied", "Realistic"),
  seed = NA
)

Arguments

psi

A function that takes an input X and returns a numeric vector with values in the range ⁠[-1,1]⁠.

beta

A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default).

centered

A logical value indicating whether to apply centering in sigma_beta (FALSE by default).

alpha

A numeric scalar representing the constraint tolerance (in ⁠[0,1/2]⁠, 0.1 by default).

B

Integer, number of Monte Carlo repetitions (1e4 by default).

ncov

Number of baseline covariates (at least 2L and 10L by default).

scenario_mu

String indicating the type of scenario for delta_Mu ("Linear", "Threshold", "Mix").

scenario_nu

String indicating the type of scenario for delta_Nu ("Linear", "Threshold", "Mix").

seed

Integer or NA (NA by default).

Value

A numeric scalar representing the expected primary outcome under the policy.


PLUCR documentation built on March 30, 2026, 5:08 p.m.