binary_S_p: Constraint function for binary policy

binary_S_pR Documentation

Constraint function for binary policy

Description

Computes the constraint function S_p, which ensures that the learned policy satisfies a constraint. This function enforces a limit on the expected impact of treatment via delta_Z.

Usage

binary_S_p(pi_X, X, alpha, delta_Nu)

Arguments

pi_X

A numeric vector of binary decisions of length n.

X

A matrix of covariates of size n x d (input data in ⁠[0,1]⁠).

alpha

A numeric scalar representing the constraint tolerance (in ⁠[0,1/2]⁠, 0.1 by default).

delta_Nu

A function of X that determines the contrast between adverse event outcomes.

Value

A numeric scalar representing the constraint function value.


PLUCR documentation built on March 30, 2026, 5:08 p.m.