View source: R/synthetic_data.R
| delta_mu_linear | R Documentation |
Computes the difference in expected Y outcomes under treatment and control, using h_Y.
delta_mu_linear(X)
X |
A matrix of covariates of size n x d (input data in |
A numeric vector that represents the contrast between primary outcomes for given X.
X <- matrix(stats::runif(10*5), 10, 5)
delta_mu_linear(X)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.