delta_mu_realistic: Realistic Conditional Average Treatment Effect estimator for...

View source: R/synthetic_data.R

delta_mu_realisticR Documentation

Realistic Conditional Average Treatment Effect estimator for Y

Description

Computes the difference in expected Y outcomes under treatment and control, using h_Y.

Usage

delta_mu_realistic(X)

Arguments

X

A matrix of covariates of size n x d (input data).

Value

A numeric vector that represents the contrast between primary outcomes for given X.

Examples

X <- matrix(stats::runif(10*5), 10, 5)
delta_mu_realistic(X)

PLUCR documentation built on March 30, 2026, 5:08 p.m.