delta_nu_realistic: Realistic Conditional Average Treatment Effect estimator for...

View source: R/synthetic_data.R

delta_nu_realisticR Documentation

Realistic Conditional Average Treatment Effect estimator for Xi

Description

Computes the difference in expected outcomes under treatment and control.

Usage

delta_nu_realistic(X)

Arguments

X

A matrix of covariates of size n x d (input data).

Value

A numeric vector that represents the contrast between adverse event outcomes for given X.

Examples

X <- matrix(stats::runif(10*5), 10, 5)
delta_nu_realistic(X)

PLUCR documentation built on March 30, 2026, 5:08 p.m.