View source: R/synthetic_data.R
| delta_nu_satisfied | R Documentation |
Computes the difference in expected outcomes under treatment and control.
delta_nu_satisfied(X)
X |
A matrix of covariates of size n x d (input data in |
A numeric vector that represents the contrast between adverse event outcomes for given X.
X <- matrix(stats::runif(10*5), 10, 5)
delta_nu_satisfied(X)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.