lwr_upper_bound_estimators: Lower and upper bound estimators for policy value and...

View source: R/process_probability.R

lwr_upper_bound_estimatorsR Documentation

Lower and upper bound estimators for policy value and constraint

Description

This function computes lower and upper confidence bounds for the policy value and constraint, respectively, based on targeted maximum likelihood estimation (TMLE) updates.

Usage

lwr_upper_bound_estimators(mu0, nu0, prop_score, pi, X, A, Y, Xi, alpha)

Arguments

mu0

A fold-specific function predicting primary outcome (Y) given treatment (A) and covariates (X).

nu0

A fold-specific function predicting adverse event outcome (Xi) given treatment (A) and covariates (X).

prop_score

A function that estimates the propensity score given treatment (A) and covariates (X).

pi

A binary treatment rule vector indicating treatment assignment under the learned decision rule.

X

A matrix or data frame of covariates of size n x d (input data in ⁠[0,1]⁠).

A

A binary vector or matrix of length n indicating treatment assignment (0 or 1).

Y

A numeric vector or matrix of length n representing primary outcomes (in ⁠[0,1]⁠).

Xi

A numeric vector or matrix of adverse events outcomes.

alpha

A numeric scalar representing the constraint tolerance (in ⁠[0,1/2]⁠, 0.1 by default).

Value

A list containing a numeric vector of length 2:

  • [1]: Lower bound for the primary outcome effect.

  • [2]: Upper bound for the adverse event effect.


PLUCR documentation built on March 30, 2026, 5:08 p.m.