make_psi: Generate psi function

View source: R/optim_functions.R

make_psiR Documentation

Generate psi function

Description

Constructs a convex combination function psi based on the sequence of solutions obtained from the Frank-Wolfe (FW) algorithm. Each new solution theta contributes to psi in the form 2 \cdot \text{expit}(X \theta) - 1.

Usage

make_psi(Theta)

Arguments

Theta

A numeric matrix (k x d). Each row theta is from FW inner minimization, used to recover an extremal point for convex function construction.

Value

A function psi that takes an input X and returns a numeric vector with values in the range ⁠[-1,1]⁠, using a convex combination of past theta solutions.


PLUCR documentation built on March 30, 2026, 5:08 p.m.