View source: R/synthetic_data.R
| model_Xi_linear | R Documentation |
Computes a linear interaction term between covariates and treatment.
model_Xi_linear(X)
X |
A matrix of covariates of size n x d (input data in |
A numeric vector with the transformed values based on covariates and treatment.
X <- matrix(stats::runif(10*5), 10, 5)
model_Xi_linear(X)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.