model_Xi_threshold: Thresholded treatment effect on Xi component function

View source: R/synthetic_data.R

model_Xi_thresholdR Documentation

Thresholded treatment effect on Xi component function

Description

Computes a threshold-based interaction term between covariates and treatment.

Usage

model_Xi_threshold(X)

Arguments

X

A matrix of covariates of size n x d (input data in ⁠[0,1]⁠).

Value

A numeric vector with the transformed values based on covariates and treatment.

Examples

X <- matrix(stats::runif(10*5), 10, 5)
model_Xi_threshold(X)

PLUCR documentation built on March 30, 2026, 5:08 p.m.