model_Y_linear: Linear treatment effect on Y component function

View source: R/synthetic_data.R

model_Y_linearR Documentation

Linear treatment effect on Y component function

Description

Computes a linear interaction term between covariates and treatment.

Usage

model_Y_linear(X, A)

Arguments

X

A matrix of covariates of size n x d (input data in ⁠[0,1]⁠).

A

A vector indicating treatment assignment (+1 or -1) for each observation.

Value

A numeric vector with the transformed values based on covariates and treatment.

Examples

X <- matrix(stats::runif(10*5), 10, 5)
A <- rep(1, 10)
model_Y_linear(X, A)

PLUCR documentation built on March 30, 2026, 5:08 p.m.