model_Y_null: No treatment effect on Y component function

View source: R/synthetic_data.R

model_Y_nullR Documentation

No treatment effect on Y component function

Description

Computes a null treatment effect for everyone

Usage

model_Y_null(X, A)

Arguments

X

A matrix of covariates of size n x d (input data in ⁠[0,1]⁠).

A

A binary vector or matrix of length n indicating treatment assignment (-1 or 1).

Value

A numeric vector with the transformed values based on covariates and treatment.

Examples

X <- matrix(stats::runif(10*5), 10, 5)
A <- rep(1, 10)
model_Y_null(X, A)

PLUCR documentation built on March 30, 2026, 5:08 p.m.