oracular_process_results: Oracular evaluation of a policy

View source: R/process_results.R

oracular_process_resultsR Documentation

Oracular evaluation of a policy

Description

This function evaluates the optimal policy derived from theta. This enables the approximation of the objective functions: risk, constraint, and the main objective and policy value.

Usage

oracular_process_results(
  theta,
  ncov = 10L,
  scenario_mu = c("Linear", "Threshold", "Mix", "Null", "Linear2", "Realistic"),
  scenario_nu = c("Linear", "Threshold", "Mix", "Satisfied", "Realistic"),
  lambda,
  alpha = 0.1,
  beta = 0.05,
  centered = FALSE
)

Arguments

theta

A numeric matrix (k x d). Each row is from FW inner minimization, used to recover an extremal point for convex function construction.

ncov

Number of baseline covariates (at least 2L and 10L by default).

scenario_mu

String indicating the type of scenario for delta_Mu ("Linear", "Threshold", "Mix", "Linear2", "Realistic").

scenario_nu

String indicating the type of scenario for delta_Nu ("Linear", "Threshold", "Mix","Satisfied", "Realistic").

lambda

A non-negative numeric scalar controlling the penalty for violating the constraint.

alpha

A numeric scalar representing the constraint tolerance (in ⁠[0,1/2]⁠, 0.1 by default).

beta

A non-negative numeric scalar controlling the sharpness of the probability function.

centered

A logical value indicating whether to apply centering in sigma_beta (FALSE by default).

Value

A vector of optimized policy parameters (theta) trained across folds.


PLUCR documentation built on March 30, 2026, 5:08 p.m.