| plot_realistic | R Documentation |
Generates and saves a two-panel plot:
one showing the sign of the treatment effect (delta_Mu) and the other
visualizing the magnitude of selection effect (delta_Nu) across covariates X.1 and X.2.
plot_realistic(delta_Mu, delta_Nu, B = 100, root.path, name)
delta_Mu |
A function that computes the treatment effect (mu difference) from covariates. |
delta_Nu |
A function that computes the selection effect (nu difference) from covariates. |
B |
Integer, number of Monte Carlo repetitions (1e4 by default). |
root.path |
Path to the folder where images are to be saved. |
name |
A string to add to the end of filename. |
Saves a plot to "Images/synthetic_setting.pdf".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.