sigma_beta: Link function

View source: R/utils.R

sigma_betaR Documentation

Link function

Description

Link function mapping ⁠[-1,1]⁠ to ⁠[0,1]⁠, parametrized by beta with an optional centering.

Usage

sigma_beta(t, beta = 0.05, centered = FALSE)

Arguments

t

A vector of numerics (in ⁠[-1,1]⁠).

beta

A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default).

centered

A logical value indicating whether to apply centering in sigma_beta (FALSE by default).

Value

A numeric vector of treatment probabilities.


PLUCR documentation built on March 30, 2026, 5:08 p.m.