sigma_beta_prime: Derivative of link function

View source: R/utils.R

sigma_beta_primeR Documentation

Derivative of link function

Description

Computes the derivative of the link function sigma_beta, with respect to t.

Usage

sigma_beta_prime(t, beta = 0.05, centered = FALSE)

Arguments

t

A vector of numerics (in ⁠[-1,1]⁠).

beta

A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default).

centered

A logical value indicating whether to apply centering in sigma_beta (FALSE by default).

Value

The derivative of sigma_beta evaluated at t.


PLUCR documentation built on March 30, 2026, 5:08 p.m.