synthetic_data_plot: Plot synthetic data setting

synthetic_data_plotR Documentation

Plot synthetic data setting

Description

Generates and saves a two-panel plot: one showing the sign of the treatment effect (delta_Mu) and the other visualizing the magnitude of selection effect (delta_Nu) across covariates X.1 and X.2.

Usage

synthetic_data_plot(delta_Mu, delta_Nu, B = 100, root.path, name)

Arguments

delta_Mu

A function that computes the treatment effect (mu difference) from covariates.

delta_Nu

A function that computes the selection effect (nu difference) from covariates.

B

Integer, number of Monte Carlo repetitions (1e4 by default).

root.path

Path to the folder where images are to be saved.

name

A string to add to the end of filename.

Value

Saves a plot to "Images/synthetic_setting.pdf".


PLUCR documentation built on March 30, 2026, 5:08 p.m.