update_mu: Update mu via augmented covariate adjustment

View source: R/alternated_procedure.R

update_muR Documentation

Update mu via augmented covariate adjustment

Description

Computes updated Mu predictions by adding the bias correction for all previous solutions at X psi(X) scaled by coefficients epsilon1_collection, then transforms back via the logistic function.

Usage

update_mu(A, X, mu0, epsilon1, theta_collection, prop_score)

Arguments

A

A binary vector or matrix of length n indicating treatment assignment (0 or 1).

X

A matrix of covariates of size n x d (input data in ⁠[0,1]⁠).

mu0

A fold-specific function predicting primary outcome (Y) given treatment (A) and covariates (X).

epsilon1

A numeric vector of GLM coefficients for each column in psi_collection.

theta_collection

A list of the optimal theta enabling the reconstruction of optimal psi functions.

prop_score

A function that estimates the propensity score given treatment (A) and covariates (X).

Value

A numeric vector of updated mu on the ⁠[0,1]⁠ scale.


PLUCR documentation built on March 30, 2026, 5:08 p.m.