update_nu: Update nu via augmented covariate adjustment

View source: R/alternated_procedure.R

update_nuR Documentation

Update nu via augmented covariate adjustment

Description

Computes updated Nu predictions by adding the bias correction for all previous solutions at X using sigma_beta scaled by coefficients epsilon2_collection, then transforms back via the logistic function.

Usage

update_nu(
  A,
  X,
  nu0,
  epsilon2,
  theta_collection,
  prop_score,
  beta = 0.05,
  centered = FALSE
)

Arguments

A

A binary vector or matrix of length n indicating treatment assignment (0 or 1).

X

A matrix of covariates of size n x d (input data in ⁠[0,1]⁠).

nu0

A fold-specific function predicting adverse event outcome (Xi) given treatment (A) and covariates (X).

epsilon2

A numeric vector of GLM coefficients for each column in sigma_psi_collection.

theta_collection

A list of the optimal theta enabling the reconstruction of optimal sigma_beta applied to psi functions.

prop_score

A function that estimates the propensity score given treatment (A) and covariates (X).

beta

A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default).

centered

A logical value indicating whether to apply centering in sigma_beta (FALSE by default).

Value

A numeric vector of updated nu on the ⁠[0,1]⁠ scale.


PLUCR documentation built on March 30, 2026, 5:08 p.m.