visual_treatment_plot: Visualize treatment assignment probability

View source: R/plot_functions.R

visual_treatment_plotR Documentation

Visualize treatment assignment probability

Description

Plots the smoothed treatment assignment probability over covariates Var_X_axis and Var_Y_axis

Usage

visual_treatment_plot(
  psi_X,
  lambda,
  beta,
  centered,
  Var_X_axis,
  Var_Y_axis,
  root.path,
  name
)

Arguments

psi_X

A numeric vector with values in the range ⁠[-1,1]⁠ representing the output of psi at fixed X.

lambda

Regularization scalar for the constraint (display purposes).

beta

A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default).

centered

A logical value indicating whether to apply centering in sigma_beta (FALSE by default).

Var_X_axis

Vector of covariates values for x-axis (length n).

Var_Y_axis

Vector of covariates values for y-axis (length n).

root.path

Path to the folder where images are to be saved.

name

A string to add to the end of filename.

Value

A message indicating that the image was saved.


PLUCR documentation built on March 30, 2026, 5:08 p.m.