| CVFolds | R Documentation |
Creates a list of row numbers for the V-fold cross validation.
CVFolds(N, id, Y, cvControl)
N |
Sample size. |
id |
Optional cluster id variable. If present, all observations in the same cluster will always be in the same split. |
Y |
outcome. |
cvControl |
Control parameters for the cross-validation step. See SuperLearner.CV.control for details. |
A list of length V where each element in the list is a vector with the row numbers of the corresponding validation sample.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.