View source: R/objective_functions.R
| Lagrangian_p | R Documentation |
Computes the objective function, which balances the risk function R_p
and the constraint function S_p using a parameter lambda.
Lagrangian_p(
psi,
X,
delta_Mu,
delta_Nu,
lambda,
alpha = 0.1,
beta = 0.05,
centered = FALSE
)
psi |
A function that takes an input |
X |
A matrix of covariates of size n x d (input data in |
delta_Mu |
A function of |
delta_Nu |
A function of |
lambda |
A non-negative numeric scalar controlling the penalty for violating the constraint. |
alpha |
A numeric scalar representing the constraint tolerance (in |
beta |
A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default). |
centered |
A logical value indicating whether to apply centering in |
A numeric scalar representing the objective function value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.