View source: R/objective_functions.R
| R_p | R Documentation |
Computes the risk function R_p for estimating the Conditional Average Treatment Effect (CATE).
The function minimizes the squared error between psi(X) and delta_Y(X).
R_p(psi, X, delta_Mu)
psi |
A function that takes an input |
X |
A matrix of covariates of size n x d (input data in |
delta_Mu |
A function of |
A numeric scalar representing the risk function value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.