| SL.grf | R Documentation |
This function trains conditional mean of a target variable for treated and control groups
using SuperLearner, applying cross-validation to compute out-of-fold estimates.
SL.grf(Y, X, newX, family, obsWeights, ...)
Y |
outcome variable |
X |
training dataframe |
newX |
test dataframe |
family |
gaussian or binomial |
obsWeights |
observation-level weights |
... |
not used |
a list containing the predictions and the fitted object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.