View source: R/objective_functions.R
| S_p | R Documentation |
Computes the constraint function S_p, which ensures that the learned policy satisfies a constraint.
This function enforces a limit on the expected impact of treatment via delta_Z.
S_p(psi, X, beta, alpha, centered, delta_Nu)
psi |
A function that takes an input |
X |
A matrix of covariates of size n x d (input data in |
beta |
A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default). |
alpha |
A numeric scalar representing the constraint tolerance (in |
centered |
A logical value indicating whether to apply centering in |
delta_Nu |
A function of |
A numeric scalar representing the constraint function value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.