| V_Pn | R Documentation |
Computes the expected outcome under a policy determined by the previously optimized psi(X).
The policy assigns treatment probabilistically based on sigma_beta(psi(X)),
and the expected outcome is calculated using counterfactual outcomes.
V_Pn(policy, y1, y0)
policy |
A numeric vector of treatment probabilities associated with |
y1 |
A numeric vector or matrix of length n representing primary outcomes under treatment (in |
y0 |
A numeric vector or matrix of length n representing primary outcomes under no treatment (in |
A numeric scalar representing the expected primary outcome under the policy.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.