| V_p | R Documentation |
Computes the expected outcome under a policy determined by the previously optimized psi(X).
The policy assigns treatment probabilistically based on sigma_beta(psi(X)),
and the expected outcome is calculated using counterfactual outcomes.
V_p(
psi,
beta = 0.05,
centered = FALSE,
alpha = 0.1,
B = 1e+06,
ncov = 10L,
scenario_mu = c("Linear", "Threshold", "Mix", "Linear2", "Null", "Realistic"),
scenario_nu = c("Linear", "Threshold", "Mix", "Satisfied", "Realistic"),
seed = NA
)
psi |
A function that takes an input |
beta |
A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default). |
centered |
A logical value indicating whether to apply centering in |
alpha |
A numeric scalar representing the constraint tolerance (in |
B |
Integer, number of Monte Carlo repetitions (1e4 by default). |
ncov |
Number of baseline covariates (at least 2L and 10L by default). |
scenario_mu |
String indicating the type of scenario for delta_Mu ("Linear", "Threshold", "Mix"). |
scenario_nu |
String indicating the type of scenario for delta_Nu ("Linear", "Threshold", "Mix"). |
seed |
Integer or NA (NA by default). |
A numeric scalar representing the expected primary outcome under the policy.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.