| binary_S_p | R Documentation |
Computes the constraint function S_p, which ensures that the learned policy satisfies a constraint.
This function enforces a limit on the expected impact of treatment via delta_Z.
binary_S_p(pi_X, X, alpha, delta_Nu)
pi_X |
A numeric vector of binary decisions of length n. |
X |
A matrix of covariates of size n x d (input data in |
alpha |
A numeric scalar representing the constraint tolerance (in |
delta_Nu |
A function of |
A numeric scalar representing the constraint function value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.