| check_data | R Documentation |
Performs quality control checks on the input data to ensure it meets expected formats and conditions.
check_data(Y, Xi, A, X, folds)
Y |
A numeric vector or matrix of length n representing primary outcomes (in |
Xi |
A numeric vector or matrix of length n indicating adverse events (0 or 1). |
A |
A binary vector or matrix of length n indicating treatment assignment (0 or 1). |
X |
A matrix or data frame of covariates of size n x d (input data in |
folds |
A list of cross-validation folds (e.g., a list of indices for each fold). |
A list with elements: ok (logical), and diagnoses (character vector of issues).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.