View source: R/process_results.R
| get_opt_beta_lambda | R Documentation |
This function loads intermediate results corresponding to lambda-optimal solutions for each beta value. It identifies and returns the beta-lambda combination that minimizes the objective function.
get_opt_beta_lambda(combinations, root.path)
combinations |
A matrix or data frame where each row corresponds to a beta and optimal-lambda pair. |
root.path |
Path to the folder where all results are to be saved. |
A vector of intermediate results including the optimal: lambda, beta, risk, constraint, obj.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.