View source: R/objective_functions.R
| grad_Lagrangian_p | R Documentation |
Computes the gradient of the objective function with respect to psi at X.
The gradient is used in optimization algorithms like Stochastic Gradient Descent (SGD).
grad_Lagrangian_p(
psi,
X,
delta_Mu,
delta_Nu,
lambda,
alpha = 0.1,
beta = 0.05,
centered = FALSE
)
grad_Lagrangian_p_X(
psi_X,
delta_Mu_X,
delta_Nu_X,
lambda,
alpha = 0.1,
beta = 0.05,
centered = FALSE
)
psi |
A function that takes an input |
X |
A matrix of covariates of size n x d (input data in |
delta_Mu |
A function of |
delta_Nu |
A function of |
lambda |
A non-negative numeric scalar controlling the penalty for violating the constraint. |
alpha |
A numeric scalar representing the constraint tolerance (in |
beta |
A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default). |
centered |
A logical value indicating whether to apply centering in |
psi_X |
The function psi evaluated at |
delta_Mu_X |
The function delta_Mu evaluated at |
delta_Nu_X |
The function delta_Nu evaluated at |
A numeric vector representing the gradient of the objective function with respect to psi(X).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.