View source: R/optim_functions.R
| make_psi | R Documentation |
Constructs a convex combination function psi based on the sequence of solutions
obtained from the Frank-Wolfe (FW) algorithm. Each new solution theta contributes
to psi in the form 2 \cdot \text{expit}(X \theta) - 1.
make_psi(Theta)
Theta |
A numeric matrix (k x d). Each row |
A function psi that takes an input X and returns a numeric vector with values in the range [-1,1],
using a convex combination of past theta solutions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.