View source: R/synthetic_data.R
| model_Xi_threshold | R Documentation |
Computes a threshold-based interaction term between covariates and treatment.
model_Xi_threshold(X)
X |
A matrix of covariates of size n x d (input data in |
A numeric vector with the transformed values based on covariates and treatment.
X <- matrix(stats::runif(10*5), 10, 5)
model_Xi_threshold(X)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.