View source: R/synthetic_data.R
| model_Y_linear | R Documentation |
Computes a linear interaction term between covariates and treatment.
model_Y_linear(X, A)
X |
A matrix of covariates of size n x d (input data in |
A |
A vector indicating treatment assignment (+1 or -1) for each observation. |
A numeric vector with the transformed values based on covariates and treatment.
X <- matrix(stats::runif(10*5), 10, 5)
A <- rep(1, 10)
model_Y_linear(X, A)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.