View source: R/synthetic_data.R
| model_Y_threshold | R Documentation |
Computes a thresholded-shaped interaction term between covariates and treatment.
model_Y_threshold(X, A)
X |
A matrix of covariates of size n x d (input data in |
A |
A binary vector or matrix of length n indicating treatment assignment (-1 or 1). |
A numeric vector with the transformed values based on covariates and treatment.
X <- matrix(stats::runif(10*5), 10, 5)
A <- rep(1, 10)
model_Y_threshold(X, A)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.