| plot_metric_comparison | R Documentation |
Creates a comparison plot of different metrics across different treatment rule estimation methods.
plot_metric_comparison(
data,
metrics = c("policy_value", "constraint"),
techniques = NULL,
root.path
)
data |
A tibble or data frame with two columns:
|
metrics |
A vector containing the metrics to be represented. |
techniques |
A vector containing the names of the techniques to be represented. |
root.path |
Path to the folder where images are to be saved. |
The function takes a data frame with method names and corresponding policy values, constraints, etc. (typically including Theta_0, Theta_naive, Theta_final, and Theta_oracular) and generates a visual comparison (e.g., bar plot or point plot).
Saves a plot to "Images/"Comparison_techniques.pdf".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.