| sigma_beta | R Documentation |
Link function mapping [-1,1] to [0,1], parametrized
by beta with an optional centering.
sigma_beta(t, beta = 0.05, centered = FALSE)
t |
A vector of numerics (in |
beta |
A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default). |
centered |
A logical value indicating whether to apply centering in |
A numeric vector of treatment probabilities.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.