| sigma_beta_prime | R Documentation |
Computes the derivative of the link function sigma_beta,
with respect to t.
sigma_beta_prime(t, beta = 0.05, centered = FALSE)
t |
A vector of numerics (in |
beta |
A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default). |
centered |
A logical value indicating whether to apply centering in |
The derivative of sigma_beta evaluated at t.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.