View source: R/alternated_procedure.R
| update_mu | R Documentation |
Computes updated Mu predictions by adding the bias correction for all previous solutions at X
psi(X) scaled by coefficients epsilon1_collection,
then transforms back via the logistic function.
update_mu(A, X, mu0, epsilon1, theta_collection, prop_score)
A |
A binary vector or matrix of length n indicating treatment assignment (0 or 1). |
X |
A matrix of covariates of size n x d (input data in |
mu0 |
A fold-specific function predicting primary outcome (Y) given treatment (A) and covariates (X). |
epsilon1 |
A numeric vector of GLM coefficients for each column in |
theta_collection |
A list of the optimal |
prop_score |
A function that estimates the propensity score given treatment (A) and covariates (X). |
A numeric vector of updated mu on the [0,1] scale.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.