View source: R/alternated_procedure.R
| update_mu_XA | R Documentation |
Computes updated Mu predictions by adding the bias correction for fixed
psi_collection scaled by coefficients epsilon1_collection,
then transforms back via the logistic function.
update_mu_XA(offset_mu_XA, epsilon1, psi_collection, H_XA)
offset_mu_XA |
A numeric vector of logit-scale baseline mu0 predictions. |
epsilon1 |
A numeric vector of GLM coefficients for each column in |
psi_collection |
A matrix whose columns are optimal |
H_XA |
A numeric vector of inverse-propensity weights, typically from |
A numeric vector of updated mu on the [0,1] scale.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.