View source: R/alternated_procedure.R
| update_nu | R Documentation |
Computes updated Nu predictions by adding the bias correction for all previous solutions at X
using sigma_beta scaled by coefficients epsilon2_collection,
then transforms back via the logistic function.
update_nu(
A,
X,
nu0,
epsilon2,
theta_collection,
prop_score,
beta = 0.05,
centered = FALSE
)
A |
A binary vector or matrix of length n indicating treatment assignment (0 or 1). |
X |
A matrix of covariates of size n x d (input data in |
nu0 |
A fold-specific function predicting adverse event outcome (Xi) given treatment (A) and covariates (X). |
epsilon2 |
A numeric vector of GLM coefficients for each column in |
theta_collection |
A list of the optimal |
prop_score |
A function that estimates the propensity score given treatment (A) and covariates (X). |
beta |
A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default). |
centered |
A logical value indicating whether to apply centering in |
A numeric vector of updated nu on the [0,1] scale.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.