View source: R/alternated_procedure.R
| update_nu_XA | R Documentation |
Computes updated Nu predictions by adding the bias correction for fixed
sigma_psi_collection scaled by coefficients epsilon2_collection,
then transforms back via the logistic function.
update_nu_XA(offset_nu_XA, epsilon2, sigma_psi_collection, H_XA)
offset_nu_XA |
A numeric vector of logit-scale baseline nu0 predictions. |
epsilon2 |
A numeric vector of GLM coefficients for each column in |
sigma_psi_collection |
A matrix whose columns are optimal |
H_XA |
A numeric vector of inverse-propensity weights, typically from |
A numeric vector of updated nu on the [0,1] scale.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.