View source: R/plot_functions.R
| visual_treatment_plot | R Documentation |
Plots the smoothed treatment assignment probability over covariates Var_X_axis and Var_Y_axis
visual_treatment_plot(
psi_X,
lambda,
beta,
centered,
Var_X_axis,
Var_Y_axis,
root.path,
name
)
psi_X |
A numeric vector with values in the range |
lambda |
Regularization scalar for the constraint (display purposes). |
beta |
A non-negative numeric scalar controlling the sharpness of the probability function (0.05 by default). |
centered |
A logical value indicating whether to apply centering in |
Var_X_axis |
Vector of covariates values for x-axis (length n). |
Var_Y_axis |
Vector of covariates values for y-axis (length n). |
root.path |
Path to the folder where images are to be saved. |
name |
A string to add to the end of filename. |
A message indicating that the image was saved.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.